$.jqplot.MarkerRenderer

The default jqPlot marker renderer, rendering the points on the line.

Summary

$.jqplot.MarkerRenderer | The default jqPlot marker renderer, rendering the points on the line.
Properties |
show | whether or not to show the marker.
style | One of diamond, circle, square, x, plus, dash, filledDiamond, filledCircle, filledSquare
lineWidth | size of the line for non-filled markers.
size | Size of the marker (diameter or circle, length of edge of square, etc.)
color | color of marker.
shadow | whether or not to draw a shadow on the line
shadowAngle | Shadow angle in degrees
shadowOffset | Shadow offset from line in pixels
shadowDepth | Number of times shadow is stroked, each stroke offset shadowOffset from the last.
shadowAlpha | Alpha channel transparency of shadow.
shadowRenderer | Renderer that will draws the shadows on the marker.
shapeRenderer | Renderer that will draw the marker.

### Properties

### show

> this.show = true

whether or not to show the marker.

### style

> this.style = 'filledCircle'

One of diamond, circle, square, x, plus, dash, filledDiamond, filledCircle, filledSquare

### lineWidth

> this.lineWidth = 2

size of the line for non-filled markers.

### size

> this.size = 9.0

Size of the marker (diameter or circle, length of edge of square, etc.)

### color

> this.color = '#666666'

color of marker. Will be set to color of series by default on init.

### shadow

> this.shadow = true

whether or not to draw a shadow on the line

### shadowAngle

> this.shadowAngle = 45

Shadow angle in degrees

### shadowOffset

> this.shadowOffset = 1

Shadow offset from line in pixels

### shadowDepth

> this.shadowDepth = 3

Number of times shadow is stroked, each stroke offset shadowOffset from the last.

### shadowAlpha

> this.shadowAlpha = '0.07'

Alpha channel transparency of shadow. 0 = transparent.

### shadowRenderer

> this.shadowRenderer = new $.jqplot.ShadowRenderer()

Renderer that will draws the shadows on the marker.

### shapeRenderer

> this.shapeRenderer = new $.jqplot.ShapeRenderer()

Renderer that will draw the marker.

> this.show = true

whether or not to show the marker.

> this.style = 'filledCircle'

One of diamond, circle, square, x, plus, dash, filledDiamond, filledCircle, filledSquare

> this.lineWidth = 2

size of the line for non-filled markers.

> this.size = 9.0

Size of the marker (diameter or circle, length of edge of square, etc.)

> this.color = '#666666'

color of marker.

> this.shadow = true

whether or not to draw a shadow on the line

> this.shadowAngle = 45

Shadow angle in degrees

> this.shadowOffset = 1

Shadow offset from line in pixels

> this.shadowDepth = 3

Number of times shadow is stroked, each stroke offset shadowOffset from the last.

> this.shadowAlpha = '0.07'

Alpha channel transparency of shadow.

> this.shadowRenderer = new $.jqplot.ShadowRenderer()

Renderer that will draws the shadows on the marker.

> this.shapeRenderer = new $.jqplot.ShapeRenderer()

Renderer that will draw the marker.
Close